GeneratedLlcsNativeBindings class final

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel(Pointer<llcs_engine> engine, int taskId) → void
override
caps(Pointer<llcs_engine> engine) Pointer<Char>
override
create(Pointer<Char> paramsJson, Pointer<Pointer<Char>> errorOut) Pointer<llcs_engine>
override
destroy(Pointer<llcs_engine> engine) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
poll(Pointer<llcs_engine> engine, int taskId, int timeoutMs) Pointer<Char>
override
stringFree(Pointer<Char> string) → void
override
submit(Pointer<llcs_engine> engine, Pointer<Char> requestJson, Pointer<Pointer<Char>> errorOut) int
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited